struct struc_texts texts[] = 
{
    {0, 0, "Here were the hans of aunt Mary."},
    {0, 0, "Ouch! Lake Balaton!"},
    {0, 0, "It was a dog, it's proprietor was a bitch."},
    {0, 0, "Russian precision!"},
    {0, 0, "Subway."},
    {0, 0, "Submarines. Blugy."},
    {0, 0, "Trafalgar square!!"},
    {0, 0, "The \"server\" room in NJSZKI."},
    {0, 0, "Segmentation fault"},
    {0, 0, "Kernel panic!"},
    {0, 0, "AN NT WORKSTATION!"},
    {1, 1, "This was as high as your IQ."},
    {1, 1, "This was the children garden."},
    {1, 2, "This was a primary school."},
    {1, 23, "Happy birthday!"},
    {2, 2, "A little boy's house, who wanted to be the president of Micros*ft Inc."},
    {2, 3, "This was the hospital of the city."},
    {3, 3, "You hit the worst school in Budapest. Congratulations!"},
    {3, 3, "They will be quiet."},
    {3, 3, "The end of the traffic jam."},
    {4, 4, "A manufacturer's office who didn't give documentation for him hardware."},
    {4, 4, "Knock-knock... Please open the door!"},
    {7, 7, "The number of the floors in this house was prime."},
    {12, 15, "The value of this was $ 1000000, now it only costs 1000000 HUF."},
    {13, 17, "Build cost was $ 10000000, demolish cost just was a button."},
    {16, 16, "The residence of Bill Gates. Thank YOU!!"},
    {18, 23, "Target destroyed."},
    {17, 23, "Your ultimate bombing URL: http://www.atom.hu/~risko/bombardier"},
    {22, 22, "WOW!"}
};
#define NUM_OF_TEXTS 29
